@@ -1,7 +1,15 @@
-from .nn import *
+from .layers import *
 from .models import *
 from .datasets import *
 from .transforms import *
+from .loss import *
+from .scheduler import *
+from .data import *
+
+try:
+    from .version import __version__  # noqa: F401
+except ImportError:
+    pass
 
 _image_backend = "PIL"
 
@@ -27,4 +35,3 @@ def get_image_backend():
     Gets the name of the package used to load images
     """
     return _image_backend
-
